{#
  Copyright (C) 2020 CERN.
  Copyright (C) 2020 Northwestern University.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{%- set title = _("Search results") %}
{%- extends config.BASE_TEMPLATE %}

{%- block javascript %}
    {{ super() }}
    {{ webpack['invenio-app-rdm-search.js'] }}
{%- endblock %}

{%- block page_body %}
<div class="ui container">
  <div data-invenio-search-config='{{ search_app_rdm_config(app_id="InvenioAppRdm.Search") | tojson }}'></div>
</div>
{%- endblock page_body %}
